#!D:\bld\gdal-split_1638630447147\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.4.0','gdalmove.py'
__requires__ = 'GDAL==3.4.0'
__import__('pkg_resources').run_script('GDAL==3.4.0', 'gdalmove.py')
